"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const action = {
    title: 'Send User Data',
    description: 'Send user ID and email to Jimo',
    platform: 'web',
    fields: {
        userId: {
            label: 'User ID',
            description: 'The unique user identifier',
            type: 'string',
            allowNull: true,
            required: false,
            default: {
                '@path': '$.userId'
            }
        },
        email: {
            label: 'User email',
            description: 'The email of the user',
            type: 'string',
            allowNull: true,
            required: false,
            default: {
                '@path': '$.traits.email'
            }
        },
        traits: {
            label: 'User Traits',
            description: 'A list of attributes coming from segment traits',
            type: 'object',
            default: {
                '@path': '$.traits'
            }
        }
    },
    defaultSubscription: 'type = "identify"',
    perform: (jimo, { payload, settings }) => {
        const browserWindow = window;
        const pushEmail = () => {
            if (payload.email == null)
                return;
            jimo.client().push(['set', 'user:email', [payload.email]]);
        };
        const pushTraits = () => {
            if (payload.traits == null)
                return;
            jimo
                .client()
                .push(['set', 'user:attributes', [payload.traits, settings.refetchExperiencesOnTraitsUpdate ?? false, true]]);
        };
        if (payload.userId != null) {
            jimo.client().push([
                'do',
                'identify',
                [
                    payload.userId,
                    () => {
                        pushEmail();
                        pushTraits();
                    }
                ]
            ]);
        }
        else {
            pushEmail();
            pushTraits();
        }
        const manualInit = settings.manualInit ?? false;
        if (manualInit &&
            payload.userId &&
            typeof payload.userId === 'string' &&
            payload.userId.length > 0 &&
            window.segmentJimo.initialized === false &&
            browserWindow.jimoInit != null) {
            browserWindow.jimoInit();
            window.segmentJimo.initialized = true;
        }
    }
};
exports.default = action;
//# sourceMappingURL=index.js.map